map

Attribute Macro map 

#[map]
Marks an async function as a request mapper.

Maps transform typed query, json, or form inputs into a new serialized upstream request payload or query string. The first owned parameter is kept as the typed map input; other supported parameters are extracted from RequestScope or request parts.