#[patch]Expand description
Declares a route inside an #[apigate::service] module.
This attribute is only expanded by #[apigate::service]; using it
directly outside a service module produces a compile error.
#[patch]Declares a route inside an #[apigate::service] module.
This attribute is only expanded by #[apigate::service]; using it
directly outside a service module produces a compile error.